@@ -1068,7 +1068,13 @@ class IPsecDriver(device_drivers.DeviceDriver):
     @log_helpers.log_method_call
     def report_status(self, context):
         status_changed_vpn_services = []
-        for process in self.processes.values():
+        for process_id, process in self.processes.items():
+            # NOTE(mnaser): It's not necessary to check status for processes
+            #               of a backup L3 agent
+            router = self.routers.get(process_id)
+            if router and router.router['ha'] and router.ha_state == 'backup':
+                LOG.debug("%s router in backup state, skipping", process_id)
+                continue
             if not self.should_be_reported(context, process):
                 continue
             previous_status = self.get_process_status_cache(process)
@@ -1102,7 +1108,7 @@ class IPsecDriver(device_drivers.DeviceDriver):
         3) VpnService is deleted during agent down
         4) RPC failure
 
-        In order to handle, these failure cases,
+        In order to handle these failure cases,
         This driver takes simple sync strategies.
         """
         vpnservices = self.agent_rpc.get_vpn_services_on_host(
