@@ -20,7 +20,7 @@ from oslo_log import log as logging
 
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils
-from neutron.plugins.common import constants
+from neutron_lib import constants
 
 from neutron_vpnaas._i18n import _
 from neutron_vpnaas.services.vpn.device_drivers import ipsec
@@ -82,7 +82,8 @@ class StrongSwanProcess(ipsec.BaseSwanProcess):
         self.DIALECT_MAP['v2'] = 'ikev2'
         self.DIALECT_MAP['sha256'] = 'sha256'
         self._strongswan_piddir = self._get_strongswan_piddir()
-        LOG.debug("strongswan piddir is '%s'" % (self._strongswan_piddir))
+        self._rootwrap_cfg = self._get_rootwrap_config()
+        LOG.debug("strongswan piddir is '%s'", (self._strongswan_piddir))
         super(StrongSwanProcess, self).__init__(conf, process_id,
                                                 vpnservice, namespace)
 
@@ -115,6 +116,8 @@ class StrongSwanProcess(ipsec.BaseSwanProcess):
             [NS_WRAPPER,
              '--mount_paths=/etc:%s/etc,%s:%s/var/run' % (
                  self.config_dir, self._strongswan_piddir, self.config_dir),
+             ('--rootwrap_config=%s' % self._rootwrap_cfg
+                 if self._rootwrap_cfg else ''),
              '--cmd=%s' % ','.join(cmd)],
             check_exit_code=check_exit_code,
             extra_ok_codes=extra_ok_codes)
@@ -179,7 +182,8 @@ class StrongSwanProcess(ipsec.BaseSwanProcess):
         self._execute([self.binary, 'start'])
         # initiate ipsec connection
         for ipsec_site_conn in self.vpnservice['ipsec_site_connections']:
-            self._execute([self.binary, 'up', ipsec_site_conn['id']])
+            self._execute([self.binary, 'stroke', 'up-nb',
+                           ipsec_site_conn['id']])
 
     def stop(self):
         self._execute([self.binary, 'stop'])
